:::{include} ../../README.md
:::

:::{toctree}
:hidden:
install
command_line
faq
user_guides/user_guides
plugins/plugins
python_api/python_api
contributing
build_docs
license
apidocs/index
genindex
:::
